@@ -182,6 +182,19 @@ class MoleculePose(BaseModel):
     )
 
 
+class CoordinateFile(BaseModel):
+    """
+    A model to describe a local coordinate file
+
+    """
+
+    filename: str = Field(
+        None, description="The filename of the atomic coordinates to use (*.pdb, *.cif)"
+    )
+
+    recentre: bool = Field(True, description="Recentre the coordinates")
+
+
 class LocalMolecule(BaseModel):
     """
     A model to describe a local molecule and its instances
@@ -302,6 +315,10 @@ class Sample(BaseModel):
         (500, 500, 500), description="The centre of rotation (A, A, A)"
     )
 
+    coords: Optional[CoordinateFile] = Field(
+        description="Coordinates to initialise the sample"
+    )
+
     molecules: Optional[Molecules] = Field(
         description="The molecules to include in the sample model"
     )
@@ -453,6 +470,7 @@ class ScanMode(str, Enum):
 
     """
 
+    manual = "manual"
     still = "still"
     tilt_series = "tilt_series"
     dose_symmetric = "dose_symmetric"
@@ -506,16 +524,16 @@ class Scan(BaseModel):
     angles: Optional[List[float]] = Field(
         None,
         description=(
-            "The list of angles to use (deg). If this is set, then the "
-            "num_images, start_angle and step_angle fields are overridden"
+            "The list of angles to use (deg). This field is used when the mode"
+            "is set to 'manual' or 'beam tilt'."
         ),
     )
 
     positions: Optional[List[float]] = Field(
         None,
         description=(
-            "The list of positions to use (A). If this is set, then the "
-            "num_images, start_pos and step_pos fields are overridden"
+            "The list of positions to use (A). This field is used when the mode"
+            "is set to 'manual' or 'beam tilt'."
         ),
     )
 
@@ -760,6 +778,41 @@ def new(filename: str = "config.yaml", full: bool = False) -> Config:
     return config
 
 
+def edit(
+    in_filename: str = "config.yaml", out_filename: str = None, config_obj: str = ""
+):
+    """
+    Edit the configuration
+
+    """
+
+    def get_config_obj(config_obj):
+        if isinstance(config_obj, str):
+            return yaml.safe_load(config_obj)
+        return config_obj
+
+    # Check the output filename
+    if out_filename is None:
+        out_filename = in_filename
+
+    # Parse the arguments
+    config = load(in_filename)
+
+    # Merge the dictionaries
+    d1 = config.dict(exclude_unset=True)
+    d2 = get_config_obj(config_obj)
+    d = deepmerge(d1, d2)
+
+    # # Load the new configuration
+    config = load(d)
+
+    # Save the config
+    save(config, out_filename, exclude_unset=True)
+
+    # Return config
+    return config
+
+
 def show(config: Config, full: bool = False):
     """
     Print the command line arguments
@@ -769,16 +822,7 @@ def show(config: Config, full: bool = False):
         full: Show the full configuration (True or False)
 
     """
-    logger.info(
-        "\n".join(
-            [
-                f"{line}"
-                for line in yaml.safe_dump(
-                    config.dict(exclude_unset=not full), indent=4
-                ).split("\n")
-            ]
-        )
-    )
+    return yaml.safe_dump(config.dict(exclude_unset=not full), indent=4)
 
 
 def deepmerge(a: dict, b: dict) -> dict:
@@ -797,6 +841,8 @@ def deepmerge(a: dict, b: dict) -> dict:
         for key, value in other.items():
             if key in self:
                 if isinstance(value, dict):
+                    if self[key] is None:
+                        self[key] = {}
                     deepmerge_internal(self[key], value)
                 else:
                     self[key] = copy.deepcopy(value)
